pitchtools.calculate_harmonic_chromatic_interval_class_from_pitch_carrier_to_pitch_carrier
==========================================================================================

.. autofunction:: abjad.tools.pitchtools.calculate_harmonic_chromatic_interval_class_from_pitch_carrier_to_pitch_carrier.calculate_harmonic_chromatic_interval_class_from_pitch_carrier_to_pitch_carrier
